summaryrefslogtreecommitdiff
path: root/regcomp.c
diff options
context:
space:
mode:
authorKarl Williamson <khw@cpan.org>2016-03-19 09:10:41 -0600
committerKarl Williamson <khw@cpan.org>2016-03-19 10:03:30 -0600
commitb084bc872b1f5913720822fd8869b542ba5ef81e (patch)
tree6189e4b959b1cca586a8122ed38b08680989333f /regcomp.c
parent0f2b45c74307980ff2b0d608d505ccbe87840a2f (diff)
downloadperl-b084bc872b1f5913720822fd8869b542ba5ef81e.tar.gz
regcomp.c, perl.c: Use 'VOL' not 'volatile'
I presume that VOL is so perl can at least compile on compilers that lack 'volatile'. (It was added by Larry in 1991 by 352d5a3ab; there were probably a lot more compilers like that back then.) But VOL is used consistently in the core, with these being the two exceptions.
Diffstat (limited to 'regcomp.c')
-rw-r--r--regcomp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/regcomp.c b/regcomp.c
index f8dc8a1bb4..646cf38a7b 100644
--- a/regcomp.c
+++ b/regcomp.c
@@ -14547,9 +14547,9 @@ S_handle_regex_sets(pTHX_ RExC_state_t *pRExC_state, SV** return_invlist,
'stack' of where the undealt-with left
parens would be if they were actually
put there */
/* The 'volatile' is a workaround for an optimiser bug
* in Solaris Studio 12.3. See RT #127455 */
- volatile IV fence = 0; /* Position of where most recent undealt-
+ VOL IV fence = 0; /* Position of where most recent undealt-
with left paren in stack is; -1 if none.
*/
STRLEN len; /* Temporary */
@@ -14547,9 +14547,9 @@ S_handle_regex_sets(pTHX_ RExC_state_t *pRExC_state, SV** return_invlist,
parens would be if they were actually
put there */
- /* The 'volatile' is a workaround for an optimiser bug
+ /* The 'VOL' (expanding to 'volatile') is a workaround for an optimiser bug
* in Solaris Studio 12.3. See RT #127455 */